phoneclientserver/phoneclient/Inc/UssdWrapper/MPhCltUssdNoteControllerCallBack.h
changeset 15 d7fc66ccd6fb
parent 0 ff3b6d0fd310
child 44 987c9837762f
--- a/phoneclientserver/phoneclient/Inc/UssdWrapper/MPhCltUssdNoteControllerCallBack.h	Fri Apr 16 15:31:58 2010 +0300
+++ b/phoneclientserver/phoneclient/Inc/UssdWrapper/MPhCltUssdNoteControllerCallBack.h	Mon May 03 13:01:45 2010 +0300
@@ -27,7 +27,7 @@
 
 /**
 *  Abstract interface for handling the notify events from note controller.
 *  User derives his class from this and implements GlobalWaitNoteDismissedL().
 *
 *  @lib phoneclient.lib
 *  @since 9.1
@@ -39,11 +39,11 @@
     public: // New functions
 
         /**
         * Called when global wait note is dismissed.
         * 
         * @param aError Error code.
         */    
-        virtual void GlobalWaitNoteDismissedL( const TInt aError ) = 0;
+        virtual void GlobalWaitNoteHidden() = 0;
     };
@@ -27,7 +27,7 @@
 /**
 *  Abstract interface for handling the notify events from note controller.
-*  User derives his class from this and implements GlobalWaitNoteDismissedL().
+*  User derives his class from this and implements GlobalWaitNoteHidden().
 *
 *  @lib phoneclient.lib
@@ -39,11 +39,11 @@
 
         /**
-        * Called when global wait note is dismissed.
+        * Called when global wait note is hidden, to background.
         * 
         * @param aError Error code.